@@ -34,11 +34,13 @@
 #include "vinagre-app.h"
 #include "vinagre-utils.h"
 #include "vinagre-prefs.h"
+#include "vinagre-cache-prefs.h"
 #include "vinagre-bacon.h"
 #include "vinagre-plugins-engine.h"
 #include "vinagre-plugin-info.h"
 #include "vinagre-plugin-info-priv.h"
 #include "vinagre-debug.h"
+#include "vinagre-ssh.h"
 
 #ifdef HAVE_TELEPATHY
 #include "vinagre-tubes-manager.h"
@@ -186,6 +188,7 @@ int main (int argc, char **argv) {
     }
 
   g_option_context_parse (context, &argc, &argv, &error);
+  g_option_context_free (context);
   if (error)
     {
       g_print ("%s\n%s\n",
@@ -200,6 +203,7 @@ int main (int argc, char **argv) {
 
   vinagre_bacon_start (servers, new_window);
 
+  vinagre_cache_prefs_init ();
   app = vinagre_app_get_default ();
   window = vinagre_app_create_window (app, NULL);
   gtk_widget_show (GTK_WIDGET(window));
@@ -220,6 +224,9 @@ int main (int argc, char **argv) {
    vinagre_tubes_manager = vinagre_tubes_manager_new (window);
 #endif
 
+  /* fake call, just to ensure this symbol will be present at vinagre.so */
+  vinagre_ssh_connect (NULL, NULL, -1, NULL, NULL, NULL, NULL, NULL);
+
   gtk_main ();
 
 #ifdef HAVE_TELEPATHY
@@ -227,6 +234,7 @@ int main (int argc, char **argv) {
 #endif
   g_object_unref (vinagre_bookmarks_get_default ());
   g_object_unref (vinagre_prefs_get_default ());
+  vinagre_cache_prefs_finalize ();
 #ifdef VINAGRE_ENABLE_AVAHI
   g_object_unref (vinagre_mdns_get_default ());
 #endif
